@@ -1,11 +1,12 @@
 test_that("concordancer works", {
-
   concordance(enron.sample[1], enron.sample[2], enron.sample[3:49],
-              search = "wants to", token.type = "word") |>
+    search = "wants to", token.type = "word"
+  ) |>
     expect_snapshot()
 
   concordance(enron.sample[1], enron.sample[2], enron.sample[3:49],
-              search = "want*", token.type = "character") |>
+    search = "want*", token.type = "character"
+  ) |>
     expect_snapshot()
 
   concordance(enron.sample[1], enron.sample[2], search = "want*", token.type = "character") |>
@@ -16,8 +17,7 @@ test_that("concordancer works", {
   enron.sents <- tokens(enron.sample, what = "sentence")
 
   concordance(enron.sents[1], enron.sents[2], enron.sents[3:49],
-              search = "? _EOS_", token.type = "word") |>
+    search = "? _EOS_", token.type = "word"
+  ) |>
     expect_snapshot()
-
-
 })
